=======
Install
=======

This chapter describes how to install icalendar as a Python package for use in your projects.


Python package with pip
-----------------------

The following command will install the icalendar package with pip.

.. code-block:: shell

    pip install icalendar

If installation is successful, you will be able to import the iCalendar package from a Python interpreter as shown.

.. code-block:: pycon

    >>> import icalendar


Debian or Ubuntu
----------------

You can install the `python-icalendar package <https://tracker.debian.org/pkg/python-icalendar>`_ for Debian or its derivatives.

.. code-block:: shell

    sudo apt-get install python3-icalendar


Fedora
------

You can install the `python3-icalendar package <https://packages.fedoraproject.org/pkgs/python-icalendar/python3-icalendar/>`_ for Fedora or its derivatives.

.. code-block:: shell

    sudo dnf install python3-icalendar
